@@ -1027,6 +1027,7 @@ class TrialMetadata(CommonColumns):
             {
                 "trial_id": ...,
                 "file_size_bytes": ..., # total file size for the trial
+                "clinical_participants": ..., # number of participants with clinical data
                 "wes": ..., # wes sample count
                 "cytof": ..., # cytof sample count
                 ... # other assays
@@ -1037,6 +1038,29 @@ class TrialMetadata(CommonColumns):
         (batches containing sample-level records), then this method will need to
         be updated to accommodate those changes.
         """
+        # Compute the total count of participants for each trial
+        participants_subquery = """
+            select
+                trial_id,
+                'total_participants' as key,
+                jsonb_array_length(metadata_json->'participants') as value
+            from
+                trial_metadata
+        """
+
+        # Compute the total  count of samples for each trial
+        samples_subquery = """
+            select
+                trial_id,
+                'total_samples' as key,
+                sum(num_samples) as value
+            from
+                trial_metadata,
+                jsonb_array_elements(metadata_json->'participants') participants,
+                jsonb_array_length(participants->'samples') num_samples
+            group by trial_id
+        """
+
         # Compute the total amount of data in bytes stored for each trial
         files_subquery = """
             select
@@ -1047,6 +1071,22 @@ class TrialMetadata(CommonColumns):
                 downloadable_files
         """
 
+        # Count how many participants have associated clinical data. The same
+        # participant may appear in multiple clinical data files, so deduplicate
+        # participants before counting them.
+        clinical_subquery = """
+            select
+                trial_id,
+                'clinical_participants' as key,
+                count(distinct participants) as value
+            from
+                trial_metadata,
+                jsonb_array_elements(metadata_json#>'{clinical_data,records}') as records,
+                jsonb_array_elements(records#>'{clinical_file,participants}') as participants
+            group by
+                trial_id
+        """
+
         # Compute the number of samples associated with each assay type for
         # assays whose metadata follows the typical structure: an array of batches,
         # with each batch containing an array of records, where each record
@@ -1129,9 +1169,11 @@ class TrialMetadata(CommonColumns):
                 jsonb_array_elements(batches->'participants') participant
         """
 
-        # All the subqueries produce the same set of columns, so `UNION`
+        # All the subqueries produce the same set of columns, so UNION ALL
         # them together into a single query, aggregating results into
         # trial-level JSON dictionaries with the shape described in the docstring.
+        # NOTE: we use UNION ALL instead of just UNION to prevent unwanted
+        # de-duplication within subquery results.
         combined_query = f"""
             select
                 jsonb_object_agg(key, value) || jsonb_object_agg('trial_id', trial_id)
@@ -1141,14 +1183,20 @@ class TrialMetadata(CommonColumns):
                     key,
                     sum(value) as value
                 from (
+                    {participants_subquery}
+                    union all
+                    {samples_subquery}
+                    union all
                     {files_subquery}
-                    union
+                    union all
+                    {clinical_subquery}
+                    union all
                     {generic_assay_subquery}
-                    union
+                    union all
                     {nanostring_subquery}
-                    union
+                    union all
                     {olink_subquery}
-                    union
+                    union all
                     {elisa_subquery}
                     union all
                     {cytof_e4412_subquery}
